import java.util.*
import kotlin.math.min

fun main() {
    // Read input
    val n = readln().toInt()
    val a = LongArray(n)
    val b = LongArray(n)
    for (i in 0 until n) {
        val ps = readln().split(" ".toRegex()).dropLastWhile { it.isEmpty() }.toTypedArray()
        a[i] = ps[0].toLong()
        b[i] = ps[1].toLong()
    }

    // Compute possible answers
    var numAns = 0
    val anss: Array<HashSet<Long>> = Array(n) { HashSet() }
    val idx: MutableMap<Long, Int> = HashMap()
    for (i in 0 until n) {
        anss[i].add(a[i] + b[i])
        anss[i].add(a[i] - b[i])
        anss[i].add(a[i] * b[i])
        for (ans in anss[i]) if (!idx.containsKey(ans)) idx[ans] = numAns++
    }

    // Create matching problem using generic max flow code
    val mf = MaxFlow(n + numAns)
    for (i in 0 until n) {
        mf.Add(mf.Source, i, 1)
        for (ans in anss[i]) mf.Add(i, n + idx[ans]!!, 1)
    }
    for (i in 0 until numAns) mf.Add(n + i, mf.Sink, 1)

    // Is the problem solvable?
    if (mf.NetworkFlow() != n) {
        print("IMPOSSIBLE")
        return
    }

    // Solvable, construct the output
    for (i in 0 until n) {
        var res: Long = -1
        var op = '#'
        if (mf.Flow[i][n + idx[a[i] + b[i]]!!] == 1) {
            op = '+'
            res = a[i] + b[i]
        } else if (mf.Flow[i][n + idx[a[i] - b[i]]!!] == 1) {
            op = '-'
            res = a[i] - b[i]
        } else if (mf.Flow[i][n + idx[a[i] * b[i]]!!] == 1) {
            op = '*'
            res = a[i] * b[i]
        } else {
            throw Exception("The impossible happened.")
        }
        print(String.format(" %d %c %d = %d", a[i], op, b[i], res))
    }
}


internal class MaxFlow(var Nodes: Int) {
    var Source: Int
    var Sink: Int
    var Capacity: Array<IntArray>
    var Neighbours: Array<LinkedList<Int>>
    var NeighbourAdded: Array<BooleanArray>
    var Flow: Array<IntArray>

    init {
        Source = Nodes
        Sink = Nodes + 1
        Nodes += 2
        Neighbours = Array(Nodes) { LinkedList() }
        Capacity = Array(Nodes) { IntArray(Nodes) }
        NeighbourAdded = Array(Nodes) { BooleanArray(Nodes) }
        Flow = Array(Nodes) { IntArray(Nodes) }
    }

    fun Add(From: Int, To: Int, Cap: Int) {
        Capacity[From][To] += Cap
        if (!NeighbourAdded[From][To]) {
            NeighbourAdded[From][To] = true
            NeighbourAdded[To][From] = true
            Neighbours[From].addLast(To)
            Neighbours[To].addLast(From)
        }
    }

    fun NetworkFlow(): Int {
        val parent = IntArray(Nodes)
        val cap = IntArray(Nodes)
        var total = 0
        while (true) {
            for (i in 0 until Nodes) parent[i] = -1
            parent[Source] = -2
            cap[Source] = Int.MAX_VALUE
            val Q: Queue<Int> = LinkedList()
            Q.offer(Source)
            while (!Q.isEmpty() && parent[Sink] == -1) {
                val act = Q.poll()
                for (next in Neighbours[act]) {
                    if (parent[next] == -1 && Capacity[act][next] > Flow[act][next]) {
                        parent[next] = act
                        cap[next] =
                            min(cap[act].toDouble(), (Capacity[act][next] - Flow[act][next]).toDouble())
                                .toInt()
                        Q.offer(next)
                    }
                }
            }
            if (parent[Sink] == -1) return total
            total += cap[Sink]
            var j = Sink
            while (j != Source) {
                Flow[parent[j]][j] += cap[Sink]
                Flow[j][parent[j]] -= cap[Sink]
                j = parent[j]
            }
        }
    }
}
